searchData={"items":[{"type":"module","title":"Entrace","doc":"Base module for starting a GenServer that performs tracing.\n\nTypically you would rather add a module to your project that uses the `Entrace.Tracer`.\n\n```elixir\ndefmodule MyApp.Tracer do\n  use Entrace.Tracer\nend\n```\n\nAnd in your application.ex list of children to supervise add:\n\n```\nMyApp.Tracer\n```\n\nIt will run as locally registered on it's module name (in this case `MyApp.Tracer`).\n\nIt is not useful to run multiple Tracer instances as the Erlang tracing facility has some limits around how many tracers you can operate.","ref":"Entrace.html"},{"type":"function","title":"Entrace.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Entrace.html#child_spec/1"},{"type":"function","title":"Entrace.list_trace_info/1","doc":"Get a map of trace info for function calls based on patterns.\n\nThe map is keyed by mfas that have been seen during the trace.\nTrace info includes information from `:erlang.trace_info/2`.\nIt includes `:call_count`, `:call_memory` and `:call_time`.","ref":"Entrace.html#list_trace_info/1"},{"type":"function","title":"Entrace.list_trace_patterns/1","doc":"Get map of trace patterns.\n\nThis should be tidied up, exposes a bit much in terms of internals.","ref":"Entrace.html#list_trace_patterns/1"},{"type":"function","title":"Entrace.start_link/1","doc":"Starts the Tracer linked to the parent process.\n\nOperations can then be performed on the resulting pid or registered name.\n\nAll options are passed along to the GenServer.start_link. There is no\nconfiguration for the tracer.","ref":"Entrace.html#start_link/1"},{"type":"function","title":"Entrace.stop/2","doc":"Stop tracing the `mfa` pattern.","ref":"Entrace.html#stop/2"},{"type":"function","title":"Entrace.trace/4","doc":"Start a trace for a provided `pattern` and `transmission` mechanism.\n\nThe `pattern` is an mfa tuple, as in `{module, function, arity}`.\nFor example `{File, read, 1}` to trace the `File.read/1` function. It\nsupports a special underscore atom `:_` to indicate a wilcard in the mfa.\nYou can only use wildcards on the function and arity and Erlang's tracing\nonly allows wildcard function if the arity is also a wildcard.\n\nThe `transmission` is one of:\n\n* a `PID` to send traces to.\n* a callback function.\n* a callback function provided as `{module, function, arity}`\n\nOptional options are available. The options are:\n\n* `limit` - the maximum number of messages to process before ending the trace\n  on that pattern. Default limit is 200.\n* `time_limit` - time to leave the trace running. If no `limit` is specified\n  this will use a larger default limit of 10_000.\n\nReturns information about how setting the trace pattern worked out.","ref":"Entrace.html#trace/4"},{"type":"function","title":"Entrace.trace_cluster/4","doc":"Start a trace across the entire cluster.\n\nSee `Entrace.trace/4` for details on arguments.","ref":"Entrace.html#trace_cluster/4"},{"type":"type","title":"Entrace.mfa_pattern/0","doc":"","ref":"Entrace.html#t:mfa_pattern/0"},{"type":"type","title":"Entrace.trace_error/0","doc":"","ref":"Entrace.html#t:trace_error/0"},{"type":"type","title":"Entrace.trace_result/0","doc":"","ref":"Entrace.html#t:trace_result/0"},{"type":"type","title":"Entrace.tracer/0","doc":"","ref":"Entrace.html#t:tracer/0"},{"type":"type","title":"Entrace.transmission/0","doc":"","ref":"Entrace.html#t:transmission/0"},{"type":"module","title":"Entrace.State","doc":"","ref":"Entrace.State.html"},{"type":"module","title":"Entrace.Trace","doc":"","ref":"Entrace.Trace.html"},{"type":"function","title":"Entrace.Trace.new/4","doc":"","ref":"Entrace.Trace.html#new/4"},{"type":"function","title":"Entrace.Trace.set_caller/2","doc":"","ref":"Entrace.Trace.html#set_caller/2"},{"type":"function","title":"Entrace.Trace.set_caller_line/2","doc":"","ref":"Entrace.Trace.html#set_caller_line/2"},{"type":"function","title":"Entrace.Trace.set_stacktrace/2","doc":"","ref":"Entrace.Trace.html#set_stacktrace/2"},{"type":"function","title":"Entrace.Trace.with_return/5","doc":"","ref":"Entrace.Trace.html#with_return/5"},{"type":"type","title":"Entrace.Trace.t/0","doc":"","ref":"Entrace.Trace.html#t:t/0"},{"type":"module","title":"Entrace.TracePattern","doc":"","ref":"Entrace.TracePattern.html"},{"type":"function","title":"Entrace.TracePattern.new/3","doc":"","ref":"Entrace.TracePattern.html#new/3"},{"type":"function","title":"Entrace.TracePattern.pop_unmatched/2","doc":"","ref":"Entrace.TracePattern.html#pop_unmatched/2"},{"type":"function","title":"Entrace.TracePattern.save_unmatched/3","doc":"","ref":"Entrace.TracePattern.html#save_unmatched/3"},{"type":"type","title":"Entrace.TracePattern.t/0","doc":"","ref":"Entrace.TracePattern.html#t:t/0"},{"type":"module","title":"Entrace.TracePatterns","doc":"","ref":"Entrace.TracePatterns.html"},{"type":"function","title":"Entrace.TracePatterns.add/3","doc":"","ref":"Entrace.TracePatterns.html#add/3"},{"type":"function","title":"Entrace.TracePatterns.count/1","doc":"","ref":"Entrace.TracePatterns.html#count/1"},{"type":"function","title":"Entrace.TracePatterns.covered?/2","doc":"","ref":"Entrace.TracePatterns.html#covered?/2"},{"type":"function","title":"Entrace.TracePatterns.covered_by/2","doc":"","ref":"Entrace.TracePatterns.html#covered_by/2"},{"type":"function","title":"Entrace.TracePatterns.exists?/2","doc":"","ref":"Entrace.TracePatterns.html#exists?/2"},{"type":"function","title":"Entrace.TracePatterns.hit/3","doc":"","ref":"Entrace.TracePatterns.html#hit/3"},{"type":"function","title":"Entrace.TracePatterns.increment/2","doc":"","ref":"Entrace.TracePatterns.html#increment/2"},{"type":"function","title":"Entrace.TracePatterns.is_match_all?/2","doc":"","ref":"Entrace.TracePatterns.html#is_match_all?/2"},{"type":"function","title":"Entrace.TracePatterns.new/0","doc":"","ref":"Entrace.TracePatterns.html#new/0"},{"type":"function","title":"Entrace.TracePatterns.remove/2","doc":"","ref":"Entrace.TracePatterns.html#remove/2"},{"type":"function","title":"Entrace.TracePatterns.within_limit?/2","doc":"","ref":"Entrace.TracePatterns.html#within_limit?/2"},{"type":"type","title":"Entrace.TracePatterns.t/0","doc":"","ref":"Entrace.TracePatterns.html#t:t/0"},{"type":"module","title":"Entrace.Tracer","doc":"","ref":"Entrace.Tracer.html"},{"type":"module","title":"Entrace.Utils","doc":"","ref":"Entrace.Utils.html"},{"type":"function","title":"Entrace.Utils.find/1","doc":"","ref":"Entrace.Utils.html#find/1"},{"type":"function","title":"Entrace.Utils.list_apps/0","doc":"","ref":"Entrace.Utils.html#list_apps/0"},{"type":"function","title":"Entrace.Utils.list_elixir_base_names/0","doc":"","ref":"Entrace.Utils.html#list_elixir_base_names/0"},{"type":"function","title":"Entrace.Utils.list_functions_for_module/1","doc":"","ref":"Entrace.Utils.html#list_functions_for_module/1"},{"type":"function","title":"Entrace.Utils.list_modules/0","doc":"","ref":"Entrace.Utils.html#list_modules/0"},{"type":"function","title":"Entrace.Utils.list_modules_by_app/1","doc":"","ref":"Entrace.Utils.html#list_modules_by_app/1"},{"type":"function","title":"Entrace.Utils.trim_elixir_namespace/1","doc":"","ref":"Entrace.Utils.html#trim_elixir_namespace/1"},{"type":"module","title":"Entrace.Utils.App","doc":"","ref":"Entrace.Utils.App.html"},{"type":"function","title":"Entrace.Utils.App.new/1","doc":"","ref":"Entrace.Utils.App.html#new/1"},{"type":"extras","title":"Entrace","doc":"# Entrace\n\nA library to make it easy to use the fantastic Erlang/OTP tracing facilities in an idiomatically Elixir way. Built-in safeties and discoverable function naming. The hope is that this makes a BEAM superpower more well-known in the Elixir community.\n\nTested to work at least as far back as OTP 24, gets more features under OTP 25/26.","ref":"readme.html"},{"type":"extras","title":"Installation - Entrace","doc":"To install, add it to `mix.exs` under the `deps`:\n\n```elixir\n# ..\n{:entrace, \"~> 0.1\"},\n# ..\n```","ref":"readme.html#installation"},{"type":"extras","title":"In an Elixir app - Entrace","doc":"Create a module for your app:\n\n```elixir\ndefmodule MyApp.Tracer do\n    use Entrace.Tracer\nend\n```\n\nIn your `application.ex` add this to your supervisor children, like an Ecto Repo or a Phoenix PubSub module:\n\n```elixir\n# ..\n  MyApp.Tracer,\n# ..\n```\n\nWhen you want to trace a function in your app from iex:\n\n```elixir\n# This will trace across your cluster\nMyApp.Tracer.trace_cluster({MyApp.TheModule, :my_function, 3}, &IO.inspect/1)\n```","ref":"readme.html#in-an-elixir-app"},{"type":"extras","title":"In a Phoenix app? - Entrace","doc":"There is another library using Entrace that will enable using it inside of Phoenix Live Dashboard. You get web UI for tracing :) Check it out at [entrace_live_dashboard](https://github.com/underjord/entrace_live_dashboard).","ref":"readme.html#in-a-phoenix-app"},{"type":"extras","title":"Using the primitives - Entrace","doc":"```elixir\n{:ok, pid} = Entrace.start_link()\nEntrace.trace_cluster(pid, {MyApp.TheModule, :my_function, 3}, &IO.inspect/1)\n```","ref":"readme.html#using-the-primitives"}],"content_type":"text/markdown"}